# API Documentation

## Core Modules
- `version_manager`: Version detection and configuration
- `ros_communicator`: ROS1/ROS2 unified communication
- `hal`: Hardware abstraction layer
- `fault_recovery`: Fault recovery system